"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Disclosure = void 0;
const base64url_1 = require("../base64url");
const error_1 = require("./error");
class Disclosure {
    constructor(salt, value, key) {
        if (typeof value === 'number' && isNaN(value)) {
            throw new error_1.SdJwtError('NaN is not allowed to be used in a disclosure.');
        }
        if (typeof value === 'number' && !isFinite(value)) {
            throw new error_1.SdJwtError('Infinite is not allowed to be used in a disclosure.');
        }
        this.salt = salt;
        this.key = key;
        this.value = value;
    }
    static fromString(s) {
        const item = base64url_1.Base64url.decodeToJson(s);
        return Disclosure.fromArray(item);
    }
    static fromArray(item) {
        return item[2] === undefined
            ? new Disclosure(item[0], item[1])
            : new Disclosure(item[0], item[2], item[1]);
    }
    get encoded() {
        return base64url_1.Base64url.encodeFromJson(this.decoded);
    }
    get decoded() {
        return this.key
            ? [this.salt, this.key, this.value]
            : [this.salt, this.value];
    }
    digest(hasher) {
        return __awaiter(this, void 0, void 0, function* () {
            // Memoize value so we don't have to re-compute
            if (!this._digest) {
                const hash = yield hasher(this.encoded);
                this._digest = base64url_1.Base64url.encode(hash);
            }
            return this._digest;
        });
    }
    toString() {
        return this.encoded;
    }
}
exports.Disclosure = Disclosure;
//# sourceMappingURL=disclosures.js.map