"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.swapClaims = void 0;
const shouldInsertDisclosure = (hasher, key, value, disclosures) => __awaiter(void 0, void 0, void 0, function* () {
    if (key !== '_sd')
        return [];
    if (!Array.isArray(value))
        return [];
    const filteredDisclosures = [];
    for (const d of disclosures) {
        const digest = yield d.digest(hasher);
        if (value.includes(digest)) {
            filteredDisclosures.push(d);
        }
    }
    return filteredDisclosures;
});
const shouldIncludeCleartextClaim = (key, value) => key !== '_sd' && key !== '_sd_alg' && typeof value !== 'object';
const swapClaims = (hasher, payload, disclosures, newPayload = {}) => __awaiter(void 0, void 0, void 0, function* () {
    const entries = Object.entries(payload);
    // Loop over de payload
    for (let i = 0; i < entries.length; i++) {
        const [key, value] = entries[i];
        // See whether we have an `_sd` key with an array of disclosures.
        const foundDisclosures = yield shouldInsertDisclosure(hasher, key, value, disclosures);
        // Add the disclosed items to the pretty payload
        foundDisclosures.forEach((d) => {
            const [, disclosureKey, disclosureValue] = d.decoded;
            newPayload[disclosureKey] = disclosureValue;
        });
        // Skip the rest as  `_sd` is a special case
        if (key === '_sd') {
            continue;
        }
        // Include all the primitive claims into the new payload
        if (shouldIncludeCleartextClaim(key, value)) {
            newPayload[key] = value;
            continue;
        }
        if (typeof value === 'object' && Array.isArray(value)) {
            newPayload[key] = yield swapClaimsInsideArray(hasher, value, disclosures);
            continue;
        }
        if (typeof value === 'object' &&
            value !== null &&
            !Array.isArray(value)) {
            newPayload[key] = yield (0, exports.swapClaims)(hasher, value, disclosures);
        }
    }
    return newPayload;
});
exports.swapClaims = swapClaims;
const swapClaimsInsideArray = (hasher, array, disclosures) => __awaiter(void 0, void 0, void 0, function* () {
    const processedArray = [];
    for (const el of array) {
        if (typeof el === 'object' && el !== null && '...' in el) {
            const hash = el['...'];
            let disclosureFound = false;
            let disclosureValue;
            for (const d of disclosures) {
                const digest = yield d.digest(hasher);
                if (digest === hash && d.decoded[2] === undefined) {
                    disclosureValue = d.decoded[1];
                    disclosureFound = true;
                    break;
                }
            }
            if (disclosureFound) {
                processedArray.push(disclosureValue);
            }
            else {
                processedArray.push(el);
            }
        }
        else {
            processedArray.push(el);
        }
    }
    return processedArray;
});
//# sourceMappingURL=swapClaim.js.map